from big3_data_main_app.custom_admin import custom_admin_site
from django.contrib import admin

from .models import SettingsMig24


@admin.register(SettingsMig24, site=custom_admin_site)
class SettingsAdmin(admin.ModelAdmin):
    pass



from enum import Enum

from django.db import models
from integrations_market.models import AbstractSettingsSingleton


class SettingsMig24(AbstractSettingsSingleton):
    class Meta:
        verbose_name = 'Настройки'
        verbose_name_plural = 'Настройки'

    def __str__(self):
        return '<<App settings "b3integration_mig24">>'



from django.core.management import call_command
from django.test import TestCase

from data_exchange_with_external_systems.constants import TaskStatuses
from integrations_market.models import IntegrationProcessStatus


class TestIntegrationCommand(TestCase):

    def test_test_completed_command(self):
        self.assertFalse(IntegrationProcessStatus.objects.exists())
        call_command("get_raw_mchd")
        integration_process_status = IntegrationProcessStatus.objects.get()
        self.assertEqual(integration_process_status.status, TaskStatuses.COMPLETED.code)

    def test_test_error_command(self):
        self.assertFalse(IntegrationProcessStatus.objects.exists())
        call_command("get_raw_mchd")
        integration_process_status = IntegrationProcessStatus.objects.get()
        self.assertEqual(integration_process_status.status, TaskStatuses.COMPLETED.code)



# Generated by Django 4.1.4 on 2024-07-31 15:42

from django.db import migrations
from django.db import models


def create_settings_object(apps, schema_editor):
    settings = apps.get_model('b3integration_mig24', 'SettingsMig24')
    settings.objects.create()


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ('integrations_market', '__latest__'),
    ]

    operations = [
        migrations.CreateModel(
            name='SettingsMig24',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'verbose_name': 'Настройки',
                'verbose_name_plural': 'Настройки',
            },
        ),
        migrations.RunPython(create_settings_object),
    ]



import logging
import time

from b3platform.integrations_market.core import AbstractIntegrationCommand


class Command(AbstractIntegrationCommand):

    @property
    def integration_name(self) -> "str":
        return "mig24"

    @property
    def process_name(self) -> "str":
        return "get_raw_mchd"

    def get_logger(self) -> "logging.Logger":
        return logging.getLogger("b3")

    def handle(self, *args, **options) -> None:
        log = self.get_logger()
        log.info("Начало работы программы.")
        time.sleep(30)
        log.info("Завершение работы программы.")
